Installation
===============

aionetiface is available on PyPI and Github. 

.. parsed-literal:: 
    python3 -m pip install aionetiface

aionetiface also comes with optional dependencies. These are required depending on
the functionality to be used. E.g. mysql packages to run a PNP server. There's
no harm in installing the extra dependencies.

.. parsed-literal:: 
    git clone https://github.com/robertsdotpm/aionetiface.git
    cd aionetiface
    python3 setup.py develop
    python3 -m pip install -r optional-test-requirements.txt

Installation on older systems
-------------------------------

The general process for getting aionetiface to work on old machines involves
getting the highest version of Python 3 work and then updating pip
using the get-pip.py script for your Python version. E.g. let's
say you get Python 3.5 to work. You would run and then
run python3 -m pip install aionetiface.

.. parsed-literal::
    https://bootstrap.pypa.io/pip/3.5/get-pip.py

Windows Vista
---------------

You will need Python 3.7 to avoid bugs with encoding on Windows Vista.
https://www.python.org/downloads/release/python-370/

Windows XP
------------

1. Apply all Windows updates from legacyupdate.net.
2. Install Visual C++ AIO Repack (it installs lots of dependencies to install software for XP)
    | Mirror 1: https://archive.org/details/visual-cpp-redist-aio-x-86-x-64-35
    | Mirror 2: https://retrosystemsrevival.blogspot.com/2020/04/visual-c-redistributable-runtimes-aio.html
3. Install Python 3.5 Runtime Redistributable to a folder in the root of your C drive (this is the only version of Python 3 I've gotten to work on XP and it has working asyncio!)
    | Mirror 1: https://archive.org/details/python-35-win-xp
    | Mirror 2: https://msfn.org/board/topic/176131-python-35-runtime-redistributable-backported-to-xp/
4. Download pip installer and run it: https://bootstrap.pypa.io/pip/3.5/get-pip.py
5. Install aionetiface: python.exe -m pip install aionetiface

